package de.entwicklercamp;

import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.Date;

import javax.imageio.ImageIO;

import lotus.domino.Database;
import lotus.domino.Document;
import lotus.domino.EmbeddedObject;
import lotus.domino.NotesException;
import lotus.domino.NotesFactory;
import lotus.domino.NotesThread;
import lotus.domino.RichTextItem;
import lotus.domino.Session;
import lotus.domino.View;

import org.apache.http.client.HttpClient;
import org.apache.http.client.ResponseHandler;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.impl.client.BasicResponseHandler;
import org.apache.http.impl.client.DefaultHttpClient;

public class HelloEntwicklerCamp {

	static Session session = null;

	public static void main(String[] args) {

		NotesThread.sinitThread();
		try {
			if (session == null || !session.isValid()) {
				System.out.println("Initialisiere Session...");
				session = NotesFactory.createSession("");
			}
			
			Database db = session.getDatabase("", "mail/tbahn.nsf");
			if (db == null) {
				throw new RuntimeException("Variable db ist gleich null");
			}
			if (!db.isOpen()) {
				throw new RuntimeException("Datenbank ist nicht offen");
			}
			
			View inboxView = db.getView("($Inbox)");
			
			iterateView(inboxView);
			
			createDocument(db, inboxView);
			
			createDocWithQuote(db, inboxView);
			
			getAndSaveConvertedGraphic(db, inboxView);
			
			inboxView.recycle();
			db.recycle();
			session.recycle();
			
		} catch (NotesException ne) {
			System.out.println("Notes-Fehler #" + ne.id + ": " + ne.text);
			ne.printStackTrace();
			
		} catch (Exception e) {
			e.printStackTrace();

		} finally {
			NotesThread.stermThread();
		}
	}

	private static void createDocument(Database db, View inboxView)
			throws NotesException {
		Document doc = db.createDocument();
		doc.replaceItemValue("Form", "Memo");
		doc.replaceItemValue("Subject", "Test: " + (new Date()));
		doc.save(true, true);
		
		doc.putInFolder(inboxView.getName());
		doc.recycle();
	}

	private static void iterateView(View inboxView) throws NotesException {
		Document doc = inboxView.getFirstDocument();
		Document nextDoc;
		do {
			nextDoc = inboxView.getNextDocument(doc);
			
			System.out.println(doc.getItemValueString("Subject"));
			
			doc.recycle();
			doc = nextDoc;
		} while (doc != null);
	}

	private static void getAndSaveConvertedGraphic(Database db, View inboxView)
			throws MalformedURLException, IOException, NotesException {
		final String GRAFIK_URL = "http://www.assono.de/web.nsf/files/img/$file/potential.jpg";
		
		URL url = new URL(GRAFIK_URL);
		BufferedImage bi = ImageIO.read(url);
		
		String fileName = "potential-" + bi.getWidth() + "x" + bi.getHeight() +".png";
		File f = new File("c:\\temp\\" + fileName);
		ImageIO.write(bi, "png", f);

		Document doc = db.createDocument();
		doc.replaceItemValue("Form", "Memo");
		doc.replaceItemValue("Subject", "Konvertierte Grafik: " + (new Date()));
		RichTextItem rtItem = doc.createRichTextItem("Body");
		rtItem.appendText("Die konvertierte Grafik:");
		rtItem.addNewLine(2);
		rtItem.embedObject(EmbeddedObject.EMBED_ATTACHMENT, null, f.getAbsolutePath(), f.getName());
		doc.save(true, true);
	      
		doc.putInFolder(inboxView.getName());
		rtItem.recycle();
		doc.recycle();
	}

	private static void createDocWithQuote(Database db, View inboxView) {
		Document doc;
		final String URL_TO_OPEN = "http://www.quotationspage.com/quote/31752.html";
		
		HttpClient client = new DefaultHttpClient();
		try {
			HttpGet httpget = new HttpGet(URL_TO_OPEN);
			ResponseHandler<String> handler = new BasicResponseHandler();
			String body = client.execute(httpget, handler);
			
			String quote = body.substring(body.indexOf("<dt>") + "<dt>".length());
			quote = quote.substring(0, quote.indexOf("</dt>"));
			String author = body.substring(body.indexOf("<title>Quote Details: ") + "<title>Quote Details: ".length());
			author = author.substring(0, author.indexOf(":"));
			
			doc = db.createDocument();
			doc.replaceItemValue("Form", "Memo");
			doc.replaceItemValue("Subject", "Ergebnis von HTTP GET: " + (new Date()));
			RichTextItem rtItem = doc.createRichTextItem("Body");
			rtItem.appendText(author + ": \"" + quote + "\"");
			doc.save(true, true);
			
			doc.putInFolder(inboxView.getName());
			rtItem.recycle();
			doc.recycle();
		} catch (Exception e) {
			System.out.println("'" + URL_TO_OPEN + "' konnte nicht geöffnet werden.");
			System.out.println(e.toString());
			e.printStackTrace();
		} finally {
			client.getConnectionManager().shutdown();
		};
	}

}
